YARP 3.3.2 (2020-02-19)                                                {#v3_3_2}
=======================

[TOC]

YARP 3.3.2 Release Notes
========================


A (partial) list of bug fixed and issues resolved in this release can be found
[here](https://github.com/robotology/yarp/issues?q=label%3A%22Fixed+in%3A+YARP+v3.3.2%22).


### Tools

##### `yarpdatadumper`

* Fixed generation of video when invoked with the command line option `--type video`


### Devices

##### `usbCamera`

* Fixed build with OpenCV 4

##### `ovrheadset`

* Fixed race condition causing randomly frame drops.
* Fixed behaviour of the `CTRL` button. Both `CTRL` buttons can now be pressed,
  only `SHIFT` will decide which eye offsets should be modified.
* Fixed `--no-logo` option.
* Fixed `--userpose` option.


Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v3.3.1..v3.3.2`):

```
    16	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
     1	Ugo Pattacini <ugo.pattacini@iit.it>
```
